@@ -96,7 +96,8 @@ Corona::Corona(bool defaultLayoutOnStartup, QString layoutNameOnStartUp, int use
       m_globalShortcuts(new GlobalShortcuts(this)),
       m_plasmaScreenPool(new PlasmaExtended::ScreenPool(this)),
       m_themeExtended(new PlasmaExtended::Theme(KSharedConfig::openConfig(), this)),
-      m_layoutsManager(new Layouts::Manager(this))
+      m_layoutsManager(new Layouts::Manager(this)),
+      m_dialogShadows(new PanelShadows(this, QStringLiteral("dialogs/background")))
 {
     //! create the window manager
 
@@ -184,6 +185,7 @@ Corona::~Corona()
     m_layoutsManager->unload();
 
     m_wm->deleteLater();
+    m_dialogShadows->deleteLater();
     m_globalShortcuts->deleteLater();
     m_layoutsManager->deleteLater();
     m_screenPool->deleteLater();
@@ -403,6 +405,11 @@ KActivities::Consumer *Corona::activitiesConsumer() const
     return m_activityConsumer;
 }
 
+PanelShadows *Corona::dialogShadows() const
+{
+    return m_dialogShadows;
+}
+
 GlobalShortcuts *Corona::globalShortcuts() const
 {
     return m_globalShortcuts;
@@ -474,7 +481,7 @@ QRegion Corona::availableScreenRegion(int id) const
     return availableScreenRegionWithCriteria(id);
 }
 
-QRegion Corona::availableScreenRegionWithCriteria(int id, QString forLayout) const
+QRegion Corona::availableScreenRegionWithCriteria(int id, QString forLayout, bool includeExternalPanels) const
 {
     const auto screens = qGuiApp->screens();
     const QScreen *screen{qGuiApp->primaryScreen()};
@@ -492,8 +499,9 @@ QRegion Corona::availableScreenRegionWithCriteria(int id, QString forLayout) con
         }
     }
 
-    if (!screen)
+    if (!screen) {
         return QRegion();
+    }
 
     QList<Latte::View *> views;
 
@@ -520,7 +528,7 @@ QRegion Corona::availableScreenRegionWithCriteria(int id, QString forLayout) con
         views = generic->latteViews();
     }
 
-    QRegion available(screen->geometry());
+    QRegion available = includeExternalPanels ? screen->availableGeometry() : screen->geometry();
 
     for (const auto *view : views) {
         if (view && view->containment() && view->screen() == screen
@@ -593,6 +601,67 @@ QRegion Corona::availableScreenRegionWithCriteria(int id, QString forLayout) con
 
                 break;
 
+            case Plasma::Types::LeftEdge:
+                if (view->behaveAsPlasmaPanel()) {
+                    available -= view->geometry();
+                } else {
+                    QRect realGeometry;
+                    int realHeight = view->maxLength() * view->height();
+
+                    switch (view->alignment()) {
+                    case Latte::Types::Top:
+                        realGeometry = QRect(view->x(), view->y(),
+                                             realThickness, realHeight);
+                        break;
+
+                    case Latte::Types::Center:
+                    case Latte::Types::Justify:
+                        realGeometry = QRect(view->x(), qMax(view->geometry().y(), view->geometry().center().y() - realHeight / 2),
+                                             realThickness, realHeight);
+                        break;
+
+                    case Latte::Types::Bottom:
+                        realGeometry = QRect(view->x(), view->geometry().bottom() - realHeight + 1,
+                                             realThickness, realHeight);
+                        break;
+                    }
+
+                    available -= realGeometry;
+                }
+
+                break;
+
+            case Plasma::Types::RightEdge:
+                if (view->behaveAsPlasmaPanel()) {
+                    available -= view->geometry();
+                } else {
+                    QRect realGeometry;
+                    int realHeight = view->maxLength() * view->height();
+                    int realX = view->geometry().right() - realThickness + 1;
+
+                    switch (view->alignment()) {
+                    case Latte::Types::Top:
+                        realGeometry = QRect(realX, view->y(),
+                                             realThickness, realHeight);
+                        break;
+
+                    case Latte::Types::Center:
+                    case Latte::Types::Justify:
+                        realGeometry = QRect(realX, qMax(view->geometry().y(), view->geometry().center().y() - realHeight / 2),
+                                             realThickness, realHeight);
+                        break;
+
+                    case Latte::Types::Bottom:
+                        realGeometry = QRect(realX, view->geometry().bottom() - realHeight + 1,
+                                             realThickness, realHeight);
+                        break;
+                    }
+
+                    available -= realGeometry;
+                }
+
+                break;
+
             default:
                 //! bypass clang warnings
                 break;
@@ -616,7 +685,7 @@ QRect Corona::availableScreenRect(int id) const
     return availableScreenRectWithCriteria(id);
 }
 
-QRect Corona::availableScreenRectWithCriteria(int id, QList<Types::Visibility> modes, QList<Plasma::Types::Location> edges) const
+QRect Corona::availableScreenRectWithCriteria(int id, QList<Types::Visibility> modes, QList<Plasma::Types::Location> edges, bool includeExternalPanels) const
 {
     const auto screens = qGuiApp->screens();
     const QScreen *screen{qGuiApp->primaryScreen()};
@@ -632,14 +701,15 @@ QRect Corona::availableScreenRectWithCriteria(int id, QList<Types::Visibility> m
         }
     }
 
-    if (!screen)
+    if (!screen) {
         return {};
+    }
 
     bool allModes = modes.isEmpty();
 
     bool allEdges = edges.isEmpty();
 
-    auto available = screen->geometry();
+    auto available = includeExternalPanels ? screen->availableGeometry() : screen->geometry();
 
     Latte::CentralLayout *currentLayout = m_layoutsManager->currentLayout();
     QList<Latte::View *> views;
