@@ -45,6 +45,7 @@
 #include <KDeclarative/KDeclarative>
 #include <KWayland/Client/plasmashell.h>
 #include <KWayland/Client/surface.h>
+#include <KWindowEffects>
 #include <KWindowSystem>
 
 // Plasma
@@ -86,6 +87,12 @@ PrimaryConfigView::PrimaryConfigView(Plasma::Containment *containment, Latte::Vi
     connect(this, &PrimaryConfigView::complexityChanged, this, &PrimaryConfigView::updateShowInlineProperties);
     connect(this, &PrimaryConfigView::complexityChanged, this, &PrimaryConfigView::syncGeometry);
 
+    connect(this, &QQuickView::statusChanged, [&](QQuickView::Status status) {
+        if (status == QQuickView::Ready) {
+            updateEffects();
+        }
+    });
+
     connections << connect(&m_screenSyncTimer, &QTimer::timeout, this, [this]() {
         setScreen(m_latteView->screen());
         setFlags(wFlags());
@@ -116,10 +123,9 @@ PrimaryConfigView::PrimaryConfigView(Plasma::Containment *containment, Latte::Vi
         m_thicknessSyncTimer.start();
     });
 
-    connections << connect(m_latteView, &Latte::View::availableScreenRectChangedForViewParts, this, &PrimaryConfigView::updateAvailableScreenGeometry);
-
     if (m_corona) {
         connections << connect(m_corona, &Latte::Corona::raiseViewsTemporaryChanged, this, &PrimaryConfigView::raiseDocksTemporaryChanged);
+        connections << connect(m_corona, &Latte::Corona::availableScreenRectChangedFrom, this, &PrimaryConfigView::updateAvailableScreenGeometry);
     }
 
     if (m_latteView->layout()) {
@@ -131,6 +137,8 @@ PrimaryConfigView::~PrimaryConfigView()
 {
     qDebug() << "ConfigView deleting ...";
 
+    m_corona->dialogShadows()->removeWindow(this);
+
     m_corona->wm()->unregisterIgnoredWindow(KWindowSystem::isPlatformX11() ? winId() : m_waylandWindowId);
 
     deleteSecondaryWindow();
@@ -150,7 +158,7 @@ void PrimaryConfigView::init()
 
     setDefaultAlphaBuffer(true);
     setColor(Qt::transparent);
-    PanelShadows::self()->addWindow(this);
+    m_corona->dialogShadows()->addWindow(this);
     rootContext()->setContextProperty(QStringLiteral("latteView"), m_latteView);
     rootContext()->setContextProperty(QStringLiteral("shortcutsEngine"), m_corona->globalShortcuts()->shortcutsTracker());
     rootContext()->setContextProperty(QStringLiteral("viewConfig"), this);
@@ -219,10 +227,10 @@ void PrimaryConfigView::deleteSecondaryWindow()
     }
 }
 
-void PrimaryConfigView::updateAvailableScreenGeometry()
-{
+void PrimaryConfigView::updateAvailableScreenGeometry(View *origin)
+{    
     int currentScrId = m_latteView->positioner()->currentScreenId();
-    m_availableScreenGeometry = m_corona->availableScreenRect(currentScrId);
+    m_availableScreenGeometry = m_corona->availableScreenRectWithCriteria(currentScrId, {}, {}, true);
 
     emit availableScreenGeometryChanged();
 }
@@ -310,7 +318,7 @@ void PrimaryConfigView::syncGeometry()
 
     position = {xPos, yPos};
 
-    updateEnabledBorders();
+    updateEnabledBorders();    
 
     m_geometryWhenVisible = QRect(position.x(), position.y(), size.width(), size.height());
 
@@ -369,8 +377,6 @@ void PrimaryConfigView::showEvent(QShowEvent *ev)
     m_corona->wm()->setViewExtraFlags(*this);
     setFlags(wFlags());
 
-    m_corona->wm()->enableBlurBehind(*this);
-
     syncGeometry();
     syncSlideEffect();
 
@@ -693,13 +699,46 @@ void PrimaryConfigView::updateEnabledBorders()
     if (m_enabledBorders != borders) {
         m_enabledBorders = borders;
 
-        PanelShadows::self()->addWindow(this, m_enabledBorders);
+        m_corona->dialogShadows()->addWindow(this, m_enabledBorders);
 
         emit enabledBordersChanged();
     }
 }
 //!END borders
 
+void PrimaryConfigView::updateEffects()
+{
+    //! Don't apply any effect before the wayland surface is created under wayland
+    //! https://bugs.kde.org/show_bug.cgi?id=392890
+    if (KWindowSystem::isPlatformWayland() && !m_shellSurface) {
+        return;
+    }
+
+    QRegion mask;
+
+    QQuickItem *rootObject = this->rootObject();
+    if (rootObject) {
+        const QVariant maskProperty = rootObject->property("backgroundMask");
+        if (static_cast<QMetaType::Type>(maskProperty.type()) == QMetaType::QRegion) {
+            qDebug() << "found 2...";
+            mask = maskProperty.value<QRegion>();
+        }
+    }
+
+    if (!mask.isEmpty()) {
+        if (KWindowSystem::compositingActive()) {
+            setMask(QRegion());
+        } else {
+            setMask(mask);
+        }
+
+        KWindowEffects::enableBlurBehind(winId(), true, mask);
+    } else {
+        setMask(QRegion());
+        KWindowEffects::enableBlurBehind(winId(), false);
+    }
+}
+
 //!BEGIN configuration
 void PrimaryConfigView::loadConfig()
 {
